@@ -1,6 +1,6 @@
-__version__ = "0.0.0"
+__version__ = "0.0.1"
 
-from . import sorted
+import advanced_collections.sorted as sorted
 from ._memlist import MemList
 from ._seglist import SegList
 
